@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -7,7 +7,7 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- *
+ * 
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
@@ -47,6 +47,8 @@ public class ASTFlattener extends GenericVisitor {
 	@Deprecated
 	private static final int JLS9= AST.JLS9;
 	
+	private static final int JLS12= AST.JLS12;
+
 	/**
 	 * The string buffer into which the serialized representation of the AST is
 	 * written.
@@ -369,11 +371,21 @@ public class ASTFlattener extends GenericVisitor {
 	 */
 	@Override
 	public boolean visit(BreakStatement node) {
-		this.fBuffer.append("break");//$NON-NLS-1$
+		int apiLevel= node.getAST().apiLevel();
+		if (apiLevel >= JLS12 && node.isImplicit() && node.getExpression() == null) {
+			return false;
+		}
+		if (apiLevel < JLS12 || (apiLevel >= JLS12 && !node.isImplicit())) {
+			this.fBuffer.append("break");//$NON-NLS-1$
+		}
 		if (node.getLabel() != null) {
 			this.fBuffer.append(" ");//$NON-NLS-1$
 			node.getLabel().accept(this);
 		}
+		if (apiLevel >= JLS12 && node.getExpression() != null) {
+			this.fBuffer.append(" ");//$NON-NLS-1$
+			node.getExpression().accept(this);
+		}
 		this.fBuffer.append(";");//$NON-NLS-1$
 		return false;
 	}
@@ -1528,37 +1540,67 @@ public class ASTFlattener extends GenericVisitor {
 		return false;
 	}
 
-	/*
-	 * @see ASTVisitor#visit(SwitchCase)
-	 */
 	@Override
 	public boolean visit(SwitchCase node) {
-		if (node.isDefault()) {
-			this.fBuffer.append("default :");//$NON-NLS-1$
+		if (node.getAST().apiLevel() >= JLS12) {
+			if (node.isDefault()) {
+				this.fBuffer.append("default");//$NON-NLS-1$
+				this.fBuffer.append(node.isSwitchLabeledRule() ? " ->" : ":");//$NON-NLS-1$ //$NON-NLS-2$
+			} else {
+				this.fBuffer.append("case ");//$NON-NLS-1$
+				for (Iterator<Expression> it= node.expressions().iterator(); it.hasNext();) {
+					Expression t= it.next();
+					t.accept(this);
+					this.fBuffer.append(it.hasNext() ? ", " : //$NON-NLS-1$
+							node.isSwitchLabeledRule() ? " ->" : ":");//$NON-NLS-1$ //$NON-NLS-2$
+				}
+			}
 		} else {
-			this.fBuffer.append("case ");//$NON-NLS-1$
-			node.getExpression().accept(this);
-			this.fBuffer.append(":");//$NON-NLS-1$
+			if (node.isDefault()) {
+				this.fBuffer.append("default :\n");//$NON-NLS-1$
+			} else {
+				this.fBuffer.append("case ");//$NON-NLS-1$
+				node.getExpression().accept(this);
+				this.fBuffer.append(":\n");//$NON-NLS-1$
+			}
 		}
 		return false;
 	}
 
-	/*
-	 * @see ASTVisitor#visit(SwitchStatement)
-	 */
 	@Override
 	public boolean visit(SwitchStatement node) {
-		this.fBuffer.append("switch (");//$NON-NLS-1$
-		node.getExpression().accept(this);
-		this.fBuffer.append(") ");//$NON-NLS-1$
-		this.fBuffer.append("{");//$NON-NLS-1$
-		for (Iterator<Statement> it= node.statements().iterator(); it.hasNext();) {
-			Statement s= it.next();
-			s.accept(this);
-		}
-		this.fBuffer.append("}");//$NON-NLS-1$
+		visitSwitchNode(node);
 		return false;
 	}
+	
+	@Override
+	public boolean visit(SwitchExpression node) {
+		visitSwitchNode(node);
+		return false;
+	}
+
+	private void visitSwitchNode(ASTNode node) {
+		this.fBuffer.append("switch (");//$NON-NLS-1$
+		if (node instanceof SwitchExpression) {
+			((SwitchExpression) node).getExpression().accept(this);
+		} else if (node instanceof SwitchStatement) {
+			((SwitchStatement) node).getExpression().accept(this);
+		}
+		this.fBuffer.append(") ");//$NON-NLS-1$
+		this.fBuffer.append("{\n");//$NON-NLS-1$
+		if (node instanceof SwitchExpression) {
+			for (Iterator<Statement> it= ((SwitchExpression) node).statements().iterator(); it.hasNext();) {
+				Statement s= it.next();
+				s.accept(this);
+			}
+		} else if (node instanceof SwitchStatement) {
+			for (Iterator<Statement> it= ((SwitchStatement) node).statements().iterator(); it.hasNext();) {
+				Statement s= it.next();
+				s.accept(this);
+			}
+		}
+		this.fBuffer.append("}\n");//$NON-NLS-1$
+	}
 
 	/*
 	 * @see ASTVisitor#visit(SynchronizedStatement)
