@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -7,7 +7,7 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- *
+ * 
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
@@ -382,6 +382,10 @@ public class GenericVisitor extends ASTVisitor {
 		endVisitNode(node);
 	}
 	@Override
+	public void endVisit(SwitchExpression node) {
+		endVisitNode(node);
+	}
+	@Override
 	public void endVisit(SwitchStatement node) {
 		endVisitNode(node);
 	}
@@ -782,6 +786,10 @@ public class GenericVisitor extends ASTVisitor {
 		return visitNode(node);
 	}
 	@Override
+	public boolean visit(SwitchExpression node) {
+		return visitNode(node);
+	}
+	@Override
 	public boolean visit(SwitchStatement node) {
 		return visitNode(node);
 	}
