@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -7,7 +7,7 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- *
+ * 
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     David Saff (saff@mit.edu) - bug 102632: [JUnit] Support for JUnit 4.
@@ -34,6 +34,7 @@ import java.util.Map;
 import java.util.Set;
 
 import org.osgi.framework.Bundle;
+import org.osgi.framework.Constants;
 
 import org.eclipse.core.runtime.Assert;
 import org.eclipse.core.runtime.CoreException;
@@ -219,18 +220,19 @@ public class JUnitLaunchConfigurationDelegate extends AbstractJavaLaunchConfigur
 			runConfig.setEnvironment(envp);
 			runConfig.setWorkingDirectory(workingDirName);
 			runConfig.setVMSpecificAttributesMap(vmAttributesMap);
-
-			if (JavaRuntime.isModularProject(javaProject)) {
-				// modulepath
+			runConfig.setPreviewEnabled(supportsPreviewFeatures(configuration));
+			
+			if (!JavaRuntime.isModularConfiguration(configuration)) {
+				// Bootpath
+				runConfig.setBootClassPath(getBootpath(configuration));
+			} else {
+				// module path
 				runConfig.setModulepath(modulepath);
 				if (!configuration.getAttribute(IJavaLaunchConfigurationConstants.ATTR_DEFAULT_MODULE_CLI_OPTIONS, true)) {
 					runConfig.setOverrideDependencies(configuration.getAttribute(IJavaLaunchConfigurationConstants.ATTR_MODULE_CLI_OPTIONS, "")); //$NON-NLS-1$
 				} else {
 					runConfig.setOverrideDependencies(getModuleCLIOptions(configuration));
 				}
-			} else {
-				// Bootpath
-				runConfig.setBootClassPath(getBootpath(configuration));
 			}
 
 			// check for cancellation
@@ -709,10 +711,16 @@ public class JUnitLaunchConfigurationDelegate extends AbstractJavaLaunchConfigur
 		private String localURL(JUnitRuntimeClasspathEntry jar) throws IOException, MalformedURLException, URISyntaxException {
 			Bundle bundle= JUnitCorePlugin.getDefault().getBundle(jar.getPluginId());
 			URL url;
-			if (jar.getPluginRelativePath() == null)
-				url= bundle.getEntry("/"); //$NON-NLS-1$
-			else
+			if (jar.getPluginRelativePath() == null) {
+				String bundleClassPath= bundle.getHeaders().get(Constants.BUNDLE_CLASSPATH);
+				url= bundleClassPath != null ? bundle.getEntry(bundleClassPath) : null;
+				if (url == null) {
+					url= bundle.getEntry("/"); //$NON-NLS-1$
+				}
+			} else {
 				url= bundle.getEntry(jar.getPluginRelativePath());
+			}
+
 			if (url == null)
 				throw new IOException();
 			return URIUtil.toFile(URIUtil.toURI(FileLocator.toFileURL(url))).getAbsolutePath(); // See bug 503050
