@@ -365,7 +365,7 @@ public final class PushDownWizard extends RefactoringWizard {
 
 			fTableViewer= new PullPushCheckboxTableViewer(table);
 			fTableViewer.setUseHashlookup(true);
-			fTableViewer.setContentProvider(new ArrayContentProvider());
+			fTableViewer.setContentProvider(ArrayContentProvider.getInstance());
 			fTableViewer.setLabelProvider(new MemberActionInfoLabelProvider());
 			fTableViewer.addSelectionChangedListener(new ISelectionChangedListener() {
 
