@@ -44,7 +44,6 @@ import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Event;
 import org.eclipse.swt.widgets.Item;
 import org.eclipse.swt.widgets.Listener;
-import org.eclipse.swt.widgets.Monitor;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.ToolBar;
 import org.eclipse.swt.widgets.Tree;
@@ -59,8 +58,8 @@ import org.eclipse.jface.action.Action;
 import org.eclipse.jface.action.ToolBarManager;
 import org.eclipse.jface.dialogs.IDialogSettings;
 import org.eclipse.jface.resource.CompositeImageDescriptor;
-import org.eclipse.jface.util.Geometry;
 import org.eclipse.jface.util.OpenStrategy;
+import org.eclipse.jface.util.Util;
 import org.eclipse.jface.viewers.IOpenListener;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.ISelectionProvider;
@@ -695,7 +694,7 @@ class BreadcrumbItemDropDown {
 		Point pt= new Point(x, rect.y + rect.height);
 		pt= fParentComposite.toDisplay(pt);
 
-		Rectangle monitor= getClosestMonitor(shell.getDisplay(), pt).getClientArea();
+		Rectangle monitor= Util.getClosestMonitor(shell.getDisplay(), pt).getClientArea();
 		int overlap= (pt.x + width) - (monitor.x + monitor.width);
 		if (overlap > 0)
 			pt.x-= overlap;
@@ -706,41 +705,6 @@ class BreadcrumbItemDropDown {
 		shell.setSize(width, height);
 	}
 
-	/**
-	 * Returns the monitor whose client area contains the given point. If no monitor contains the
-	 * point, returns the monitor that is closest to the point.
-	 * <p>
-	 * Copied from <code>org.eclipse.jface.window.Window.getClosestMonitor(Display, Point)</code>
-	 * </p>
-	 *
-	 * @param display the display showing the monitors
-	 * @param point point to find (display coordinates)
-	 * @return the monitor closest to the given point
-	 */
-	private static Monitor getClosestMonitor(Display display, Point point) {
-		int closest= Integer.MAX_VALUE;
-
-		Monitor[] monitors= display.getMonitors();
-		Monitor result= monitors[0];
-
-		for (int i= 0; i < monitors.length; i++) {
-			Monitor current= monitors[i];
-
-			Rectangle clientArea= current.getClientArea();
-
-			if (clientArea.contains(point))
-				return current;
-
-			int distance= Geometry.distanceSquared(Geometry.centerPoint(clientArea), point);
-			if (distance < closest) {
-				closest= distance;
-				result= current;
-			}
-		}
-
-		return result;
-	}
-
 	/**
 	 * Set the size of the given shell such that more content can be shown. The shell size does not
 	 * exceed a user-configurable maximum.
