@@ -43,12 +43,16 @@ import org.eclipse.swt.widgets.Text;
 import org.eclipse.swt.widgets.Tree;
 import org.eclipse.swt.widgets.TreeItem;
 
+import org.eclipse.core.commands.Command;
+import org.eclipse.core.expressions.Expression;
+
 import org.eclipse.core.runtime.CoreException;
 
 import org.eclipse.jface.action.Action;
 import org.eclipse.jface.action.IAction;
 import org.eclipse.jface.action.IMenuManager;
 import org.eclipse.jface.bindings.TriggerSequence;
+import org.eclipse.jface.commands.ActionHandler;
 import org.eclipse.jface.dialogs.Dialog;
 import org.eclipse.jface.dialogs.IDialogSettings;
 import org.eclipse.jface.dialogs.PopupDialog;
@@ -69,12 +73,11 @@ import org.eclipse.jface.text.IInformationControlExtension2;
 
 import org.eclipse.ui.IEditorPart;
 import org.eclipse.ui.IWorkbenchCommandConstants;
+import org.eclipse.ui.LegacyHandlerSubmissionExpression;
 import org.eclipse.ui.PlatformUI;
-import org.eclipse.ui.commands.ActionHandler;
-import org.eclipse.ui.commands.HandlerSubmission;
-import org.eclipse.ui.commands.ICommand;
-import org.eclipse.ui.commands.ICommandManager;
-import org.eclipse.ui.commands.Priority;
+import org.eclipse.ui.commands.ICommandService;
+import org.eclipse.ui.handlers.IHandlerActivation;
+import org.eclipse.ui.handlers.IHandlerService;
 import org.eclipse.ui.keys.IBindingService;
 
 import org.eclipse.jdt.core.IJavaElement;
@@ -165,7 +168,7 @@ public abstract class AbstractInformationControl extends PopupDialog implements
 	private TreeViewer fTreeViewer;
 	/** The current string matcher */
 	protected JavaElementPrefixPatternMatcher fPatternMatcher;
-	private ICommand fInvokingCommand;
+	private Command fInvokingCommand;
 	private TriggerSequence[] fInvokingCommandKeySequences;
 
 	/**
@@ -178,7 +181,7 @@ public abstract class AbstractInformationControl extends PopupDialog implements
 	private CustomFiltersActionGroup fCustomFiltersActionGroup;
 
 	private IAction fShowViewMenuAction;
-	private HandlerSubmission fShowViewMenuHandlerSubmission;
+	private IHandlerActivation fShowViewMenuHandlerActivation;
 
 	/**
 	 * Field for tree style since it must be remembered by the instance.
@@ -206,8 +209,8 @@ public abstract class AbstractInformationControl extends PopupDialog implements
 	public AbstractInformationControl(Shell parent, int shellStyle, int treeStyle, String invokingCommandId, boolean showStatusField) {
 		super(parent, shellStyle, true, true, false, true, true, null, null);
 		if (invokingCommandId != null) {
-			ICommandManager commandManager= PlatformUI.getWorkbench().getCommandSupport().getCommandManager();
-			fInvokingCommand= commandManager.getCommand(invokingCommandId);
+			ICommandService commandService= PlatformUI.getWorkbench().getService(ICommandService.class);
+			fInvokingCommand= commandService.getCommand(invokingCommandId);
 			if (fInvokingCommand != null && !fInvokingCommand.isDefined())
 				fInvokingCommand= null;
 			else
@@ -669,10 +672,10 @@ public abstract class AbstractInformationControl extends PopupDialog implements
 	 * @since 3.2
 	 */
 	protected void addHandlerAndKeyBindingSupport() {
-		// Register action with command support
-		if (fShowViewMenuHandlerSubmission == null) {
-			fShowViewMenuHandlerSubmission= new HandlerSubmission(null, getShell(), null, fShowViewMenuAction.getActionDefinitionId(), new ActionHandler(fShowViewMenuAction), Priority.MEDIUM);
-			PlatformUI.getWorkbench().getCommandSupport().addHandlerSubmission(fShowViewMenuHandlerSubmission);
+		if (fShowViewMenuHandlerActivation == null) {
+			IHandlerService handlerService= PlatformUI.getWorkbench().getService(IHandlerService.class);
+			Expression expression= new LegacyHandlerSubmissionExpression(null, getShell(), null);
+			fShowViewMenuHandlerActivation= handlerService.activateHandler(fShowViewMenuAction.getActionDefinitionId(), new ActionHandler(fShowViewMenuAction), expression);
 		}
 	}
 
@@ -682,9 +685,11 @@ public abstract class AbstractInformationControl extends PopupDialog implements
 	 * @since 3.2
 	 */
 	protected void removeHandlerAndKeyBindingSupport() {
-		// Remove handler submission
-		if (fShowViewMenuHandlerSubmission != null)
-			PlatformUI.getWorkbench().getCommandSupport().removeHandlerSubmission(fShowViewMenuHandlerSubmission);
+		if (fShowViewMenuHandlerActivation != null) {
+			IHandlerService handlerService= PlatformUI.getWorkbench().getService(IHandlerService.class);
+			handlerService.deactivateHandler(fShowViewMenuHandlerActivation);
+			fShowViewMenuHandlerActivation= null;
+		}
 
 	}
 
@@ -768,7 +773,7 @@ public abstract class AbstractInformationControl extends PopupDialog implements
 		getShell().removeFocusListener(listener);
 	}
 
-	final protected ICommand getInvokingCommand() {
+	final protected Command getInvokingCommand() {
 		return fInvokingCommand;
 	}
 
