@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -7,7 +7,7 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- *
+ * 
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     Renaud Waldura &lt;renaud+eclipse@waldura.com&gt; - New class/interface with wizard
@@ -59,6 +59,7 @@ import org.eclipse.jdt.core.ITypeRoot;
 import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.core.Signature;
+import org.eclipse.jdt.core.compiler.IProblem;
 import org.eclipse.jdt.core.dom.AST;
 import org.eclipse.jdt.core.dom.ASTMatcher;
 import org.eclipse.jdt.core.dom.ASTNode;
@@ -80,6 +81,7 @@ import org.eclipse.jdt.core.dom.IPackageBinding;
 import org.eclipse.jdt.core.dom.ITypeBinding;
 import org.eclipse.jdt.core.dom.IVariableBinding;
 import org.eclipse.jdt.core.dom.ImportDeclaration;
+import org.eclipse.jdt.core.dom.LambdaExpression;
 import org.eclipse.jdt.core.dom.MemberValuePair;
 import org.eclipse.jdt.core.dom.MethodDeclaration;
 import org.eclipse.jdt.core.dom.MethodInvocation;
@@ -99,6 +101,7 @@ import org.eclipse.jdt.core.dom.SuperConstructorInvocation;
 import org.eclipse.jdt.core.dom.SuperFieldAccess;
 import org.eclipse.jdt.core.dom.SuperMethodInvocation;
 import org.eclipse.jdt.core.dom.SwitchCase;
+import org.eclipse.jdt.core.dom.SwitchExpression;
 import org.eclipse.jdt.core.dom.SwitchStatement;
 import org.eclipse.jdt.core.dom.ThisExpression;
 import org.eclipse.jdt.core.dom.ThrowStatement;
@@ -113,10 +116,10 @@ import org.eclipse.jdt.core.manipulation.TypeKinds;
 import org.eclipse.jdt.core.refactoring.CompilationUnitChange;
 import org.eclipse.jdt.core.search.IJavaSearchConstants;
 
+import org.eclipse.jdt.internal.core.manipulation.StubUtility;
 import org.eclipse.jdt.internal.core.manipulation.dom.ASTResolving;
 import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 import org.eclipse.jdt.internal.corext.codemanipulation.ContextSensitiveImportRewriteContext;
-import org.eclipse.jdt.internal.corext.codemanipulation.StubUtility;
 import org.eclipse.jdt.internal.corext.dom.ASTNodeFactory;
 import org.eclipse.jdt.internal.corext.dom.ASTNodes;
 import org.eclipse.jdt.internal.corext.dom.Bindings;
@@ -232,8 +235,14 @@ public class UnresolvedElementsSubProcessor {
 						typeKind= TypeKinds.REF_TYPES;
 						suggestVariableProposals= false;
 					}
-				} else if (locationInParent == SwitchCase.EXPRESSION_PROPERTY) {
-					ITypeBinding switchExp= ((SwitchStatement) node.getParent().getParent()).getExpression().resolveTypeBinding();
+				} else if (locationInParent == SwitchCase.EXPRESSION_PROPERTY || locationInParent == SwitchCase.EXPRESSIONS2_PROPERTY) {
+					ASTNode caseParent= node.getParent().getParent();
+					ITypeBinding switchExp= null;
+					if (caseParent instanceof SwitchStatement) {
+						switchExp= ((SwitchStatement) caseParent).getExpression().resolveTypeBinding();
+					} else if (caseParent instanceof SwitchExpression) {
+						switchExp= ((SwitchExpression) caseParent).getExpression().resolveTypeBinding();
+					}
 					if (switchExp != null && switchExp.isEnum()) {
 						binding= switchExp;
 					}
@@ -630,13 +639,35 @@ public class UnresolvedElementsSubProcessor {
 			return;
 		}
 
-		if (node instanceof SimpleName && !JavaModelUtil.is10OrHigher(javaProject)) {
-			String[] args= problem.getProblemArguments();
-			if (args != null && args.length > 0) {
-				String name= args[0];
-				if (name.equals("var")) { //$NON-NLS-1$
-					ReorgCorrectionsSubProcessor.getNeedHigherComplianceProposals(context, problem, proposals, JavaCore.VERSION_10);
+		if (node instanceof SimpleName && !JavaModelUtil.is11OrHigher(javaProject)) {
+			boolean isVarTypeProblem= false;
+			if (problem.getProblemId() == IProblem.VarIsNotAllowedHere) {
+				isVarTypeProblem= true;
+			} else {
+				String[] args= problem.getProblemArguments();
+				if (args != null && args.length > 0) {
+					String name= args[0];
+					if (name.equals("var")) { //$NON-NLS-1$
+						isVarTypeProblem= true;
+					}
+				}				
+			}
+			if (isVarTypeProblem) {
+				// check if "var" is present as lambda parameter type
+				boolean isVarInLambdaParamType= false;
+				ASTNode parent= node.getParent();
+				if (parent instanceof SimpleType && parent.getLocationInParent() == SingleVariableDeclaration.TYPE_PROPERTY) {
+					parent= parent.getParent();
+					if (parent.getLocationInParent() == LambdaExpression.PARAMETERS_PROPERTY) {
+						isVarInLambdaParamType= true;
+					}						
 				}
+				
+				if (isVarInLambdaParamType) {
+					ReorgCorrectionsSubProcessor.getNeedHigherComplianceProposals(context, problem, proposals, JavaCore.VERSION_11);
+				} else {
+					ReorgCorrectionsSubProcessor.getNeedHigherComplianceProposals(context, problem, proposals, JavaCore.VERSION_10);						
+				}		
 			}
 		}
 
@@ -1145,16 +1176,13 @@ public class UnresolvedElementsSubProcessor {
 			for (IPackageFragment enclosingPackage : matchingPackageFragments) {
 				if (enclosingPackage.isReadOnly()) { // This is to handle the case where the enclosingPackage belongs to a jar file
 					IPackageFragmentRoot root= (IPackageFragmentRoot) enclosingPackage.getAncestor(IJavaElement.PACKAGE_FRAGMENT_ROOT);
-					if (root != null) {
-						projectModule= root.getModuleDescription();
-					}
+					projectModule= ModuleCorrectionsSubProcessor.getModuleDescription(root);
 				} else {
 					IJavaProject project= enclosingPackage.getJavaProject();
-					if (project != null && JavaModelUtil.is9OrHigher(project)) {
-						projectModule= project.getModuleDescription();
-					}
+					projectModule= ModuleCorrectionsSubProcessor.getModuleDescription(project);
 				}
-				if (projectModule != null && projectModule.exists() && !projectModule.equals(currentModuleDescription)) {
+				if (projectModule != null && ((projectModule.exists() && !projectModule.equals(currentModuleDescription))
+						|| projectModule.isAutoModule())) {
 					String moduleName= projectModule.getElementName();
 					if (!modules.contains(moduleName)) {
 						String[] args= { moduleName };
