@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -7,7 +7,7 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- *
+ * 
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
@@ -63,7 +63,8 @@ public class BuildPathSupport {
 	private static final String[] PREFS_COMPLIANCE= new String[] {
 			JavaCore.COMPILER_PB_ASSERT_IDENTIFIER, JavaCore.COMPILER_PB_ENUM_IDENTIFIER,
 			JavaCore.COMPILER_SOURCE, JavaCore.COMPILER_CODEGEN_TARGET_PLATFORM,
-			JavaCore.COMPILER_COMPLIANCE, JavaCore.COMPILER_RELEASE
+			JavaCore.COMPILER_COMPLIANCE, JavaCore.COMPILER_RELEASE,
+			JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES, JavaCore.COMPILER_PB_REPORT_PREVIEW_FEATURES
 	};
 
 
@@ -418,6 +419,8 @@ public class BuildPathSupport {
 	 * <li>{@link JavaCore#COMPILER_PB_ASSERT_IDENTIFIER}</li>
 	 * <li>{@link JavaCore#COMPILER_PB_ENUM_IDENTIFIER}</li>
 	 * <li>{@link JavaCore#COMPILER_CODEGEN_INLINE_JSR_BYTECODE} for compliance levels 1.5 and greater</li>
+	 * <li>{@link JavaCore#COMPILER_PB_ENABLE_PREVIEW_FEATURES} for compliance levels 11 and greater</li>
+	 * <li>{@link JavaCore#COMPILER_PB_REPORT_PREVIEW_FEATURES} for compliance levels 11 and greater</li>
 	 * </ul>
 	 * 
 	 * @param ee the EE, can be <code>null</code>
