@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -47,6 +47,8 @@ import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 import org.eclipse.jdt.internal.ui.wizards.buildpaths.ModuleEncapsulationDetail.LimitModules;
 import org.eclipse.jdt.internal.ui.wizards.buildpaths.ModuleEncapsulationDetail.ModuleAddExport;
+import org.eclipse.jdt.internal.ui.wizards.buildpaths.ModuleEncapsulationDetail.ModuleAddExpose;
+import org.eclipse.jdt.internal.ui.wizards.buildpaths.ModuleEncapsulationDetail.ModuleAddOpens;
 import org.eclipse.jdt.internal.ui.wizards.buildpaths.ModuleEncapsulationDetail.ModuleAddReads;
 import org.eclipse.jdt.internal.ui.wizards.buildpaths.ModuleEncapsulationDetail.ModulePatch;
 
@@ -251,6 +253,10 @@ public class CPListElement {
 					if (!encodedExports.isEmpty()) {
 						res.add(JavaCore.newClasspathAttribute(IClasspathAttribute.ADD_EXPORTS, encodedExports));
 					}
+					String encodedOpens= ModuleEncapsulationDetail.encodeFiltered(detailValue, ModuleAddOpens.class);
+					if (!encodedOpens.isEmpty()) {
+						res.add(JavaCore.newClasspathAttribute(IClasspathAttribute.ADD_OPENS, encodedOpens));
+					}
 					String encodedReads= ModuleEncapsulationDetail.encodeFiltered(detailValue, ModuleAddReads.class);
 					if (!encodedReads.isEmpty()) {
 						res.add(JavaCore.newClasspathAttribute(IClasspathAttribute.ADD_READS, encodedReads));
@@ -453,8 +459,10 @@ public class CPListElement {
 		}
 	}
 
-	private void createAttributeElement(String key, Object value, boolean builtIn) {
-		fChildren.add(new CPListElementAttribute(this, key, value, builtIn));
+	public CPListElementAttribute createAttributeElement(String key, Object value, boolean builtIn) {
+		CPListElementAttribute attribute= new CPListElementAttribute(this, key, value, builtIn);
+		fChildren.add(attribute);
+		return attribute;
 	}
 
 	private static boolean isFiltered(Object entry, String[] filteredKeys) {
@@ -591,7 +599,15 @@ public class CPListElement {
 	public boolean equals(Object other) {
 		if (other != null && other.getClass().equals(getClass())) {
 			CPListElement elem= (CPListElement) other;
-			return getClasspathEntry().equals(elem.getClasspathEntry());
+			if (!getClasspathEntry().equals(elem.getClasspathEntry())) {
+				return false;
+			}
+			if (this.fModule != null && elem.fModule != null) {
+				if (!this.fModule.equals(elem.fModule)) {
+					return false;
+				}
+			}
+			return this.fModule == null && elem.fModule == null;
 		}
 		return false;
 	}
@@ -603,7 +619,11 @@ public class CPListElement {
 	public int hashCode() {
 		if(fPath==null)
 			return super.hashCode();
-		return fPath.hashCode() + fEntryKind;
+		int code= fPath.hashCode() + fEntryKind;
+		if (this.fModule != null) {
+			code= 31 * code + this.fModule.hashCode();
+		}
+		return code;
 	}
 
 	@Override
@@ -782,9 +802,11 @@ public class CPListElement {
 			for (int j= 0; j < extraAttributes.length; j++) {
 				IClasspathAttribute otherAttrib= extraAttributes[j];
 				if (IClasspathAttribute.PATCH_MODULE.equals(otherAttrib.getName())) {
-					details.add(ModulePatch.fromString(attribElem, otherAttrib.getValue()));
+					details.addAll(ModulePatch.fromMultiString(attribElem, otherAttrib.getValue()));
 				} else if (IClasspathAttribute.ADD_EXPORTS.equals(otherAttrib.getName())) {
-					details.addAll(ModuleAddExport.fromMultiString(attribElem, otherAttrib.getValue()));
+					details.addAll(ModuleAddExpose.fromMultiString(attribElem, otherAttrib.getValue(), true));
+				} else if (IClasspathAttribute.ADD_OPENS.equals(otherAttrib.getName())) {
+					details.addAll(ModuleAddExpose.fromMultiString(attribElem, otherAttrib.getValue(), false));
 				} else if (IClasspathAttribute.ADD_READS.equals(otherAttrib.getName())) {
 					details.addAll(ModuleAddReads.fromMultiString(attribElem, otherAttrib.getValue()));
 				} else if (IClasspathAttribute.LIMIT_MODULES.equals(otherAttrib.getName())) {
@@ -799,7 +821,7 @@ public class CPListElement {
 
 	private static boolean isModuleAttribute(String attributeName) {
 		return Stream.of(IClasspathAttribute.MODULE, IClasspathAttribute.LIMIT_MODULES,
-					IClasspathAttribute.PATCH_MODULE, IClasspathAttribute.ADD_EXPORTS, IClasspathAttribute.ADD_READS)
+					IClasspathAttribute.PATCH_MODULE, IClasspathAttribute.ADD_EXPORTS, IClasspathAttribute.ADD_OPENS, IClasspathAttribute.ADD_READS)
 				.anyMatch(attributeName::equals);
 	}
 
@@ -880,6 +902,8 @@ public class CPListElement {
 									buf.append(IClasspathAttribute.PATCH_MODULE+':'+detail.toString()).append(';');
 								if (detail instanceof ModuleAddExport)
 									buf.append(IClasspathAttribute.ADD_EXPORTS+':'+detail.toString()).append(';');
+								if (detail instanceof ModuleAddOpens)
+									buf.append(IClasspathAttribute.ADD_OPENS+':'+detail.toString()).append(';');
 								if (detail instanceof ModuleAddReads)
 									buf.append(IClasspathAttribute.ADD_READS+':'+detail.toString()).append(';');
 								if (detail instanceof LimitModules)
