@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2017, 2018 GK Software SE, and others.
+ * Copyright (c) 2017, 2019 GK Software SE, and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -17,6 +17,7 @@ import static org.eclipse.swt.events.SelectionListener.widgetSelectedAdapter;
 
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -28,6 +29,7 @@ import java.util.Set;
 import org.eclipse.equinox.bidi.StructuredTextTypeHandlerFactory;
 
 import org.eclipse.swt.SWT;
+import org.eclipse.swt.events.SelectionListener;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
@@ -85,6 +87,7 @@ import org.eclipse.jdt.internal.ui.refactoring.contentassist.JavaPrecomputedName
 import org.eclipse.jdt.internal.ui.wizards.NewWizardMessages;
 import org.eclipse.jdt.internal.ui.wizards.buildpaths.ModuleEncapsulationDetail.LimitModules;
 import org.eclipse.jdt.internal.ui.wizards.buildpaths.ModuleEncapsulationDetail.ModuleAddExport;
+import org.eclipse.jdt.internal.ui.wizards.buildpaths.ModuleEncapsulationDetail.ModuleAddExpose;
 import org.eclipse.jdt.internal.ui.wizards.buildpaths.ModuleEncapsulationDetail.ModuleAddReads;
 import org.eclipse.jdt.internal.ui.wizards.buildpaths.ModuleEncapsulationDetail.ModulePatch;
 import org.eclipse.jdt.internal.ui.wizards.dialogfields.DialogField;
@@ -177,6 +180,8 @@ public class ModuleDialog extends StatusDialog {
 	private static final int IDX_INCLUDED= 1;
 	private static final int IDX_IMPLICITLY_INCLUDED= 2;
 	
+	private BuildPathBasePage fBasePage;
+
 	private Button fAddIncludedButton;
 	private Button fRemoveIncludedButton;
 	private Button fPromoteIncludedButton;
@@ -184,7 +189,7 @@ public class ModuleDialog extends StatusDialog {
 	private final SelectionButtonDialogField fIsPatchCheckbox;
 	private final StringDialogField fPatchedModule;
 	
-	private final ListDialogField<ModuleAddExport> fAddExportsList;
+	private final ListDialogField<ModuleAddExpose> fAddExportsList;
 
 	private final ListDialogField<ModuleAddReads> fAddReadsList;
 	
@@ -200,9 +205,10 @@ public class ModuleDialog extends StatusDialog {
 	private static final int IDX_REMOVE= 2;
 
 
-	public ModuleDialog(Shell parent, CPListElement entryToEdit, IJavaElement[] selectedElements) {
+	public ModuleDialog(Shell parent, CPListElement entryToEdit, IJavaElement[] selectedElements, BuildPathBasePage basePage) {
 		super(parent);
 
+		fBasePage= basePage;
 		fCurrCPElement= entryToEdit;
 		fJavaElements= selectedElements;
 
@@ -225,7 +231,7 @@ public class ModuleDialog extends StatusDialog {
 		fPatchedModule.setLabelText(NewWizardMessages.ModuleDialog_patched_module_label);
 		fPatchedModule.setDialogFieldListener(field -> validateDetails(field));
 
-		fAddExportsList= createDetailListContents(entryToEdit, NewWizardMessages.ModuleDialog_exports_label, new AddExportsAdapter(), ModuleAddExport.class);
+		fAddExportsList= createDetailListContents(entryToEdit, NewWizardMessages.ModuleDialog_exports_label, new AddExportsAdapter(), ModuleAddExpose.class);
 		fAddReadsList= createDetailListContents(entryToEdit, NewWizardMessages.ModuleDialog_reads_label, new AddReadsAdapter(), ModuleAddReads.class);
 
 		initializeValues();
@@ -294,8 +300,21 @@ public class ModuleDialog extends StatusDialog {
 		tabFolder.addSelectionListener(widgetSelectedAdapter(e -> validateTab(e.widget, tabItemContents, tabItemDetails)));
 
 		applyDialogFont(composite);
+		updateStatus(new StatusInfo(IStatus.WARNING, NewWizardMessages.ModuleDialog_deprecated_warning));
 		return composite;
 	}
+	
+	@Override
+	protected void createButtonsForButtonBar(Composite parent) {
+		if (fBasePage.fSWTControl != null) {
+			Button switchButton= createButton(parent, 2, NewWizardMessages.ModuleDialog_switchToTab_button, false);
+			switchButton.addSelectionListener(SelectionListener.widgetSelectedAdapter(e -> {
+				fBasePage.switchToTab(ModuleDependenciesPage.class);
+				cancelPressed();
+			}));
+		}
+		super.createButtonsForButtonBar(parent);
+	}
 
 	private String getDescriptionString() {
 		String desc;
@@ -522,7 +541,7 @@ public class ModuleDialog extends StatusDialog {
 		}
 	}
 
-	public static void configureModuleContentAssist(Text textControl, Set<String> moduleNames) {
+	public static void configureModuleContentAssist(Text textControl, Collection<String> moduleNames) {
 		if (moduleNames.size() == 1) {
 			textControl.setText(moduleNames.iterator().next());
 		} else if (!moduleNames.isEmpty()) {
@@ -635,7 +654,7 @@ public class ModuleDialog extends StatusDialog {
 			}
 		}
 		if (status.isOK()) {
-			for (ModuleAddExport export : fAddExportsList.getElements()) {
+			for (ModuleAddExpose export : fAddExportsList.getElements()) {
 				if (!packages.add(export.fPackage)) {
 					status.setError(Messages.format(NewWizardMessages.ModuleDialog_duplicatePackage_error, export.fPackage));
 					break;
@@ -917,24 +936,24 @@ public class ModuleDialog extends StatusDialog {
 		abstract void editEntry(ListDialogField<T> field, T detail);
 	}
 
-	private class AddExportsAdapter extends ListAdapter<ModuleAddExport> {
+	private class AddExportsAdapter extends ListAdapter<ModuleAddExpose> {
 
 		@Override
-		void addEntry(ListDialogField<ModuleAddExport> field) {
+		void addEntry(ListDialogField<ModuleAddExpose> field) {
 			ModuleAddExport initialValue= new ModuleAddExport(getSourceModuleName(), NO_NAME, getCurrentModuleName(), null);
-			ModuleAddExportsDialog dialog= new ModuleAddExportsDialog(getShell(), fJavaElements, initialValue);
+			ModuleAddExportsDialog dialog= new ModuleAddExportsDialog(getShell(), fJavaElements, null, initialValue);
 			if (dialog.open() == Window.OK) {
-				ModuleAddExport export= dialog.getExport(fCurrCPElement.findAttributeElement(CPListElement.MODULE));
+				ModuleAddExpose export= dialog.getExport(fCurrCPElement.findAttributeElement(CPListElement.MODULE));
 				if (export != null)
 					field.addElement(export);
 			}
 		}
 
 		@Override
-		void editEntry(ListDialogField<ModuleAddExport> field, ModuleAddExport export) {
-			ModuleAddExportsDialog dialog= new ModuleAddExportsDialog(getShell(), fJavaElements, export);
+		void editEntry(ListDialogField<ModuleAddExpose> field, ModuleAddExpose export) {
+			ModuleAddExportsDialog dialog= new ModuleAddExportsDialog(getShell(), fJavaElements, null, export);
 			if (dialog.open() == Window.OK) {
-				ModuleAddExport newExport= dialog.getExport(fCurrCPElement.findAttributeElement(CPListElement.MODULE));
+				ModuleAddExpose newExport= dialog.getExport(fCurrCPElement.findAttributeElement(CPListElement.MODULE));
 				if (newExport != null) {
 					field.replaceElement(export, newExport);
 				} else {
